PostalAddress

Struct PostalAddress 

pub struct PostalAddress {
    pub type: Option<i32>,
    pub label: Option<String>,
    pub street: Option<String>,
    pub pobox: Option<String>,
    pub neighborhood: Option<String>,
    pub city: Option<String>,
    pub region: Option<String>,
    pub postcode: Option<String>,
    pub country: Option<String>,
}

Fields

type: Option<i32>label: Option<String>street: Option<String>pobox: Option<String>neighborhood: Option<String>city: Option<String>region: Option<String>postcode: Option<String>country: Option<String>

Implementations

Source

impl PostalAddress

pub fn type(&self) -> Type

Returns the enum value of type, or the default if the field is unset or set to an invalid enum value.

pub fn set_type(&mut self, value: Type)

Sets type to the provided enum value.

pub fn label(&self) -> &str

Returns the value of label, or the default value if label is unset.

pub fn street(&self) -> &str

Returns the value of street, or the default value if street is unset.

pub fn pobox(&self) -> &str

Returns the value of pobox, or the default value if pobox is unset.

pub fn neighborhood(&self) -> &str

Returns the value of neighborhood, or the default value if neighborhood is unset.

pub fn city(&self) -> &str

Returns the value of city, or the default value if city is unset.

pub fn region(&self) -> &str

Returns the value of region, or the default value if region is unset.

pub fn postcode(&self) -> &str

Returns the value of postcode, or the default value if postcode is unset.

pub fn country(&self) -> &str

Returns the value of country, or the default value if country is unset.